/***************************************************************

	InternetSuite.r

	Version:	1.3

	Copyright:	 1991-1999 by Apple Computer, Inc., All rights reserved.


 ***************************************************************/


#include <MacTypes.r>
#include <Dialogs.r>
#include <AEUserTermTypes.r>
#include <AppleEvents.r>
#include <AERegistry.r>
#include <ASRegistry.r>
#include "FinderEventsRegistry.h"
#include "FolderActionRegistry.r"
#include "AEInternetRegistry.r"
#include <AEDataModel.r>


/* Macros to improve readability of terminology entries */
#define Reserved3  reserved, reserved, reserved
#define Reserved8  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved9  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved12 reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved13 reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved27 Reserved13, Reserved13, reserved
#define bindingReserveHolder tightBindingFunction, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define isPlural "",{"",kAESpecialClassProperties,cType,"",reserved,singleItem,notEnumerated,readOnly,Reserved8,noApostrophe,notFeminine,notMasculine,plural},{}


resource kAETerminologyExtension (0, "Internet Suite") {
	0x1, 0x0, english, roman,
	{	
/*

Internet Suite
Classes and commands for Internet scripting
Note that these are included in Standard Additions terminology and are available systemwide.
You do not include definitions from this suite in application terminology, but may adapt
these classes and events for your own application.

*/
	"Internet suite", "Standard terms for Internet scripting", kAEInternetSuite, 1, 1,

		{
/* Events handled by Standard Addition event handlers */
		"open location", "Opens a URL with the appropriate program (your favorite browser)", 'GURL', 'GURL', noReply, "", replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3, typeChar, "the URL to open", directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{
			"error reporting", 'errr', 'bool', "should error conditions be reported in a dialog?",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},

/* Event prototype for events handled by CGI script applications*/
		"handle CGI request", "Sent to a script to process a Common Gateway Interface request", KAEISWebStarSuite, kAEISHandleCGI, cHTML, "An HTML page resulting from the CGI execution", replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3, typeChar, "the path of the URL", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{
			"searching for", kAEISHTTPSearchArgs, typeChar, "the data for the GET method or data after the ? in a POST method",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"with posted data", kAEISPostArgs, typeChar, "the POST arguments",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"of content type", kAEISContentType, typeChar, "the MIME content type of POST arguments",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"using access method", kAEISMethod, typeChar, "either GET or POST",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"from address", cAddress, typeChar, "the IP address of the entity making the request",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"from user", kAEISUserName, typeChar, "the user name associated with the request",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"using password", kAEISPassword, typeChar, "the password sent with the request",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"with user info", kAEISFromUser, typeChar, "additional information about the user, usually the email address",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"from server", kAEISServerName, typeChar, "the name of the server application sending this request",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"via port", kAEISServerPort, typeChar, "the IP port number of the server",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"executing by", kAEISScriptName, typeChar, "the path to the script executing this CGI, in URL form",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"referred by", kAEISReferrer, typeChar, "the URL of the page the client used to link to the CGI",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"from browser", kAEISUserAgent, typeChar, "the name of the client software",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"using action", kAEISActionPath, typeChar, "the path to the file or CGI",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"of action type", kAEISAction, typeChar, "either PREPROCESSOR, POSTPROCESSOR, CGI, or ACGI",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"from client IP address", kAEISClientIP, typeChar, "the Internet address of the client",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"with full request", kAEISFullRequest, typeChar, "the full request as sent to the server",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			"with connection ID", 'Kcid', typeInteger, "the ID of the connection from the server to the client",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			}
		},

/* Classes */
		{
		
		"URL", cURL, "A Universal Resource Locator or Universal Resource ID (URI)",
			{
			"properties", 'pALL', typeAERecord, "property that allows getting and setting of multiple properties",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"name", pName, typeChar, "a name given to this URL, usually the name of the page it refers to",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"scheme", pScheme, eScheme, "the access scheme",
				reserved, singleItem, enumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"host", pHost, cInternetAddress, "the host specified by this URL",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"path", pPath, typeChar, "the location of the target on the host",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"user name", pUserName, typeChar, "the user name by which to access this URL",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"password", pPassword, typeChar, "the password by which to access this URL",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			}, { },
		
		"URLs", cURL, isPlural,
		
		"Internet address", cInternetAddress, "An Internet or Intranet address for the TCP/IP protocol",
			{
			"properties", 'pALL', typeAERecord, "property that allows getting and setting of multiple properties",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"DNS form", pDNSForm, typeChar, "the Domain Name System form of the address (e.g. apple.com)",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"dotted decimal form", pDottedDecimal, typeChar, "the dotted-decimal form of the address (e.g. 17.255.1.1)",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"port", pPort, typeInteger, "the port number of the requested TCP/IP service",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			}, { },
		
		"Internet addresses", cInternetAddress, isPlural,
		
		"web page", cHTML, "A web page in HyperText Markup Language form",
			{
			"properties", 'pALL', typeAERecord, "property that allows getting and setting of multiple properties",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"name", pName, typeChar, "the name of the web page",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"URL", pURL, cUrl, "the universal resource locator for this page",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"text encoding", pTextEncoding, typeChar, "the text encoding method used for this page",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			}, { },
		
		"web pages", cHTML, isPlural,
		
		"FTP item", cFTPItem, "An item on an FTP server",
			{
			"properties", 'pALL', typeAERecord, "property that allows getting and setting of multiple properties",
				reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"name", pName, typeChar, "the name of the FTP item",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"URL", pURL, cUrl, "the universal resource locator for this item",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			"kind", pFTPKind, typeCHar, "the kind of the FTP item (directory or file)",
				reserved, singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			}, { },
		
		"FTP items", cFTPItem, isPlural,

		}, 
		
		{ },

/* Enumerations */
		{			
			eScheme,
			{	
				"http URL", eurlHTTP, "",
				"secure http URL", eurlHTTPS, "",
				"ftp URL",  eurlFTP, "",
				"mail URL" , eurlMail, "",
				"file URL", eurlFile, "",
				"gopher URL", eurlGopher, "",
				"telnet URL", eurlTelnet, "",
				"news URL", eurlNews, "",
				"secure news URL", eurlSNews, "",
				"nntp URL", eurlNNTP, "",
				"message URL", eurlMessage, "",
				"mailbox URL", eurlMailbox, "",
				"multi URL", eurlMulti, "",
				"launch URL", eurlLaunch, "",
				"afp URL", eurlAFP, "",
				"AppleTalk URL", eurlAT, "",
				"unknown URL", eurlUnknown, ""
			}
		}

	},


};